# CloudiotDevice


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**num_id** | **int** |  | 
**task_topic** | **str** |  | [readonly] 
**config_topic** | **str** |  | [readonly] 
**state_topic** | **str** |  | [readonly] 
**gcp_project_id** | **str** |  | [readonly] 
**gcp_region** | **str** |  | [readonly] 
**gcp_cloudiot_device_registry** | **str** |  | [readonly] 
**mqtt_bridge_hostname** | **str** |  | [readonly] 
**mqtt_bridge_port** | **int** |  | [readonly] 
**mqtt_client_id** | **str** |  | [readonly] 
**name** | **str** |  | 
**id** | **str** |  | 
**device** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


